@@ -1,7 +1,7 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.3.2';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.3.3';
 #pod =encoding UTF-8
 #pod
 #pod =head1 SYNOPSIS
@@ -56,6 +56,8 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.3.2';
 #pod     #
 #pod     # Conversion and replacements
 #pod     #
+#pod     [Authority]
+#pod
 #pod     [PkgVersion]
 #pod     die_on_existing_version = 1
 #pod     die_on_line_insertion   = 1
@@ -98,7 +100,15 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.3.2';
 #pod     [CheckSelfDependency]
 #pod
 #pod     #
-#pod     # Auto generation --- distribution files
+#pod     # Auto generation --- meta info
+#pod     #
+#pod     [Authority]
+#pod     do_munging = 0
+#pod     [MetaProvides::Package]
+#pod     [MetaConfig]
+#pod
+#pod     #
+#pod     # Auto generation --- generate files
 #pod     #
 #pod     [ModuleBuild]
 #pod     [MetaYAML]
@@ -116,9 +126,6 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.3.2';
 #pod     directory = eg
 #pod     directory = examples
 #pod
-#pod     [MetaProvides::Package]
-#pod     [MetaConfig]
-#pod
 #pod     #
 #pod     # Auto generation --- tests
 #pod     #
@@ -234,17 +241,18 @@ sub configure {
         @{ $self->payload->{'GatherDir.exclude_match'} || [] },
         # ...with the default options (exclude certain files at top level)
         # note: cpanfile is parsed by [Prereqs::FromCPANfile] and the release version created
+        # note: each subdir is matched separately, i.e. not the whole file path
         qw(
             ^cpanfile$
             ^cpanfile.snapshot$
-            ^\w+\.ini$
+            ^(?!(dist|weaver)\.ini)\w+\.ini$
             ^\w+\.tar\.gz$
-            ^extlib\b
-            ^local\b
-            ^\.build\b
-            ^\.git\b
-            ^\.svn\b
-            ^CVS\b
+            ^extlib$
+            ^local$
+            ^\.build$
+            ^\.git$
+            ^\.svn$
+            ^CVS$
         )
     );
 
@@ -312,7 +320,16 @@ sub configure {
         'CheckSelfDependency',            # Make sure no packages of this dist ended up in the prerequisites list
 
         #
-        # Auto generation --- distribution files
+        # Auto generation --- meta info
+        #
+        ['Authority' => {                 # Add authority
+            'do_munging' => 0,
+        }],
+        'MetaProvides::Package',          # specify provided packages in META.* instead of letting PAUSE figure them out
+        'MetaConfig',                     # add Dist::Zilla info to META.*
+
+        #
+        # Auto generation --- generate files
         #
         'ModuleBuildTiny',                # add Build.PL that will use Module::Build::Tiny to install the distribution
         'Manifest',                       # add Manifest (list of all files)
@@ -330,8 +347,6 @@ sub configure {
                 ) ] )
                 : (),
         }],
-        'MetaProvides::Package',          # specify provided packages in META.* instead of letting PAUSE figure them out
-        'MetaConfig',                     # add Dist::Zilla info to META.*
 
         #
         # Auto generation --- tests
@@ -391,32 +406,39 @@ __PACKAGE__->meta->make_immutable;
 
 {
     package Dist::Zilla::Plugin::ShareDir::ProjectDistDir;
-    # ABSTRACT: install a directory's contents as "ShareDir" content
-$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '3.3.2';
-use Moose;
+    # ABSTRACT: install "ShareDir" content and make other modules happy
+$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '3.3.3';
+    # fullfill File::ShareDir::ProjectDistDir strict mode and be compatible with Module::Build::Tiny
+
+    use Moose;
     use namespace::autoclean;
 
+    with 'Dist::Zilla::Role::FileMunger';
     with 'Dist::Zilla::Role::ShareDir';
 
-     use File::Spec;
+    use File::Spec;
 
+    # FileMunger plugins are executed before ShareDir plugins, so the ShareDir
+    # code below will see the already moved files.
+
+    # In contrast to Dist::Zilla::Plugin::ShareDir we use this for the munger
     has dir => (
         is     => 'ro',
         isa    => 'Str',
-        lazy_build => 1,
+        lazy => 1,
+        default => sub {
+            my ($self) = @_;
+            return File::Spec->catfile('share', 'dist', $self->zilla->name);
+        },
     );
 
-    sub _build_dir {
+    #
+    # ShareDir code
+    #
+    sub find_files { # Required by Dist::Zilla::Role::ShareDir
         my ($self) = @_;
-        return File::Spec->catfile('share', 'dist', $self->zilla->name),
-    }
-
-    sub find_files {
-        my ($self) = @_;
-        my $dir = $self->dir;
         return [
-            grep { index($_->name, "$dir/") == 0 }
-                @{ $self->zilla->files }
+            grep { index($_->name, "share/") == 0 } @{ $self->zilla->files }
         ];
     }
 
@@ -424,7 +446,26 @@ use Moose;
         my ($self) = @_;
         my $files = $self->find_files;
         return unless @$files;
-        return { dist => $self->dir };
+        return { dist => "share" };
+    }
+
+    #
+    # FileMunger code
+    #
+    # Moves files from share/dist/My-Dist to share/ to comply with Module::Build::Tiny
+    sub munge_files {
+        my ($self) = @_;
+        for my $file (@{ $self->zilla->files }) {
+            my @dirs = File::Spec->splitdir($file->name);
+            # process files under share/
+            next unless $dirs[0] eq "share";
+            # if the sharedir equals $self->dir (i.e. share/dist/My-Dist per default)
+            if (File::Spec->catdir(@dirs[0..2]) eq $self->dir) {
+
+                splice(@dirs, 1, 2);
+                $file->name( File::Spec->catdir(@dirs) );
+            }
+        }
     }
 
     __PACKAGE__->meta->make_immutable;
@@ -433,7 +474,7 @@ use Moose;
 {
     package Dist::Zilla::Plugin::MAXHQ::BundleDepsDeep;
     # ABSTRACT: register all needed plugins in a bundle as runtime requirements
-$Dist::Zilla::Plugin::MAXHQ::BundleDepsDeep::VERSION = '3.3.2';
+$Dist::Zilla::Plugin::MAXHQ::BundleDepsDeep::VERSION = '3.3.3';
 use Moose;
     use namespace::autoclean;
 
@@ -442,12 +483,6 @@ use Moose;
     use Module::Metadata;
     use Distribution::Metadata;
 
-    sub _warn {
-        my $name = __PACKAGE__;
-        $name =~ s/^Dist::Zilla::Plugin:://;
-        warn sprintf("[%s] %s\n", $name, join("", @_));
-    }
-
     sub register_prereqs {
         my ($self) = @_;
 
@@ -460,7 +495,7 @@ use Moose;
         # plugins of the pluginbundle will be used later, so the prerequisites
         # are needed.
         #
-        _warn("Copying plugins from phase 'develop' to 'runtime'");
+        $self->log("Copying plugins from phase 'develop' to 'runtime'");
         my $devreq = $cpan_req->requirements_for('develop', 'requires'); # class CPAN::Meta::Requirements
         my $devreq_str = $devreq->as_string_hash;
         $self->zilla->register_prereqs(
@@ -475,13 +510,13 @@ use Moose;
         # Add all active plugins as runtime requirements
         # (if not already there with a version number)
         #
-        _warn("Registering currently used plugins as 'runtime' requirements");
+        $self->log("Registering currently used plugins as 'runtime' requirements");
 
         # Try to find list of Dist::Zilla's own packages
         my $dzil_meta = Distribution::Metadata->new_from_module("Dist::Zilla");
         my $dzil_pkg = {};
         if ($dzil_meta->install_json) {
-            _warn "Excluding packages of Dist::Zilla distribution";
+            $self->log("Excluding packages of Dist::Zilla distribution");
             $dzil_pkg = $dzil_meta->install_json_hash->{provides};
         }
 
@@ -531,7 +566,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 3.3.2
+version 3.3.3
 
 =head1 SYNOPSIS
 
@@ -588,6 +623,8 @@ Currently this plugin bundle is equivalent to:
     #
     # Conversion and replacements
     #
+    [Authority]
+
     [PkgVersion]
     die_on_existing_version = 1
     die_on_line_insertion   = 1
@@ -630,7 +667,15 @@ Currently this plugin bundle is equivalent to:
     [CheckSelfDependency]
 
     #
-    # Auto generation --- distribution files
+    # Auto generation --- meta info
+    #
+    [Authority]
+    do_munging = 0
+    [MetaProvides::Package]
+    [MetaConfig]
+
+    #
+    # Auto generation --- generate files
     #
     [ModuleBuild]
     [MetaYAML]
@@ -648,9 +693,6 @@ Currently this plugin bundle is equivalent to:
     directory = eg
     directory = examples
 
-    [MetaProvides::Package]
-    [MetaConfig]
-
     #
     # Auto generation --- tests
     #
